@@ -13,7 +13,10 @@
 # pylint:disable=missing-module-docstring
 
 import logging
-from typing import Dict
+from typing import (
+    Dict,
+    Optional,
+)
 from urllib.parse import urljoin
 
 from gql import Client
@@ -25,7 +28,10 @@ from qctrl.builders.http_transport import (
     QctrlGqlClient,
     QctrlRequestsHTTPTransport,
 )
-from qctrl.constants import OIDC_CLIENT_ID
+from qctrl.constants import (
+    OIDC_CLIENT_ID,
+    ORGANIZATION_SLUG_HEADER,
+)
 from qctrl.qctrlauth.session import QctrlOAuth2Session
 from qctrl.utils import (
     check_client_version,
@@ -108,19 +114,23 @@ def create_client_auth(oidc_url: str) -> ClientAuthBase:
 
 @check_client_version
 def create_gql_client(
-    api_root: str, auth: ClientAuthBase = None, headers: Dict = None
+    api_root: str,
+    auth: Optional[ClientAuthBase] = None,
+    headers: Optional[Dict] = None,
+    organization_slug: Optional[str] = None,
 ) -> Client:
     """Creates a gql client.
 
     Parameters
     ----------
-    auth: ClientAuthBase
+    auth : ClientAuthBase
         The auth object.
-    api_root: str
+    api_root : str
         The host url.
-    headers: Dict
-        HTTP headers
-
+    headers : Dict
+        HTTP headers.
+    organization_slug : str, optional
+        Organization slug for single tenant allocation.
 
     Returns
     -------
@@ -132,6 +142,9 @@ def create_gql_client(
     LOGGER.debug("gql url: %s", url)
     headers = headers or {}
 
+    if organization_slug:
+        headers[ORGANIZATION_SLUG_HEADER] = organization_slug
+
     headers.update(
         {
             "Content-Encoding": "gzip",
