@@ -19,7 +19,7 @@ the `qctrl` package.
 
 # pylint: disable=unused-import
 
-from qctrltoolkit import (
+from boulderopaltoolkits import (
     FUNCTIONS,
     NODES,
     TOOLKIT_ATTR,
